/**
 * @module package/ecoyn/dashboard/bin/backend/controls/cards/SalesComparison
 * @author www.pcsg.de (Serpil Ülker)
 */

define('package/ecoyn/dashboard/bin/backend/controls/cards/SalesComparison', [

    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',
    'Ajax',
    'Locale',
    'Mustache',

    URL_OPT_DIR + 'bin/quiqqer-asset/chart.js/chart.js/dist/chart.umd.js'

], function (QUICard, Utils, QUIAjax, QUILocale, Mustache, Chart) {
    "use strict";

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/SalesComparison',

        Binds: [
            '$onCreate'
        ],

        initialize: function (options) {
            this.parent(options);

            this.setAttribute({
                content : '',
                priority: 85
            });

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }


            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getSalesComparison', function (r) {
                    let result = r.data;
                    let interval = r.interval;

                    const Elm = self.getElm();
                    const Body = Elm.getElement('.card-body');
                    Body.set('html', '');

                    const isEmpty = function (result) {
                        for (let i = 0, len = result.length; i < len; i++) {
                            if (result[i].netSum !== 0) {
                                return false;
                            }
                        }

                        return true;
                    };

                    if (isEmpty(result)) {
                        Body.set('html', QUILocale.get('ecoyn/dashboard', 'no.results'));

                        resolve();
                        return;
                    }

                    const Canvas = new Element('canvas', {
                        'class': "canvas-test",
                        style  : {
                            height: 80
                        }
                    }).inject(Body);

                    Body.setStyle('display', null);

                    let netSum = [];
                    let timeframe = [];

                    result.forEach(function (entry) {
                        netSum.push(entry.netSum);

                        let from = entry.from;

                        switch (interval) {
                            case 'days':
                                from = from.replace(' 00:00:00', '');
                                from = from.replace(' 23:59:59', '');
                                break;

                            case 'months':
                                from = from.substring(0, 7);
                                break;

                            case 'years':
                                from = from.substring(0, 4);
                                break;
                        }

                        timeframe.push(from);
                    });


                    new Chart(Canvas, {
                        type: 'bar',
                        data: {
                            labels  : timeframe,
                            datasets: [
                                {
                                    label          : QUILocale.get('ecoyn/dashboard', 'ecoyn.comparison'),
                                    data           : netSum,
                                    borderColor    : '#00e0a2b3',
                                    backgroundColor: '#00e0a2b3',
                                }
                            ]
                        }
                    });

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            const self = this;

            if (!Utils.getBoard()) {
                return;
            }

            this.getElm().classList.add('col-sg-6');
            this.getElm().classList.add('col-sm-6');

            Utils.getBoard().addEvent('onChange', function () {
                self.refresh();
            });
        }
    });
});
