/**
 * @module package/quiqqer/dashboard/bin/backend/controls/cards/TopCustomer
 *
 * @author www.pcsg.de (Serpil Ülker)

 */

define('package/ecoyn/dashboard/bin/backend/controls/cards/TopCustomer', [

    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',
    'Ajax',
    'Locale',
    'Mustache',

    'text!package/ecoyn/dashboard/bin/backend/controls/cards/TopCustomer.html'
], function (QUICard, Utils, QUIAjax, QUILocale, Mustache, contentTemplate) {
    "use strict";

    const lg = 'ecoyn/dashboard';

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/TopCustomer',

        Binds: [
            '$onCreate'
        ],

        options: {},

        initialize: function (options) {
            this.parent(options);

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }

            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getTopCustomer', function (result) {
                    const Tbody = self.getElm().getElement('tbody');
                    Tbody.set('html', '');


                    if (typeOf(result) === 'array' && !result.length) {
                        Tbody.set(
                            'html',
                            '<tr><td colspan="2">' + QUILocale.get('ecoyn/dashboard', 'no.results') + '</td></tr>'
                        );
                        
                        resolve();
                        return;
                    }

                    const data = result;
                    let i, len, entry, Row;

                    const click = function (event) {
                        let Target = event.target;

                        if (Target.nodeName !== 'TR') {
                            Target = Target.getParent('tr');
                        }

                        window.parent.require([
                            'utils/Panels',
                            'controls/users/User'
                        ], function (PanelUtils, UsersPanel) {
                            PanelUtils.openPanelInTasks(
                                new UsersPanel(Target.get('id'))
                            );
                        });
                    };

                    for (i = 0, len = data.length; i < len; i++) {
                        entry = data[i];

                        Row = new Element('tr', {
                            'class': 'ecoyn-dashboard-top-customer',
                            id     : entry.id,
                            title  : entry.title,
                            html   : '<td>' + entry.id + '</td>' +
                                     '<td>' + entry.title + '</td>'
                        }).inject(Tbody);

                        Row.getElements('td').addEvent('click', click);
                    }

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            const self = this;

            if (!Utils.getBoard()) {
                return;
            }

            this.$Content.addClass('card-table ecoyn-dashboard-top-customer');
            this.$Content.removeClass('card-body');

            this.getElm().classList.add('col-sg-6');
            this.getElm().classList.add('col-sm-6');

            self.setAttributes({
                head_title: QUILocale.get(lg, 'ecoyn.top.customer.title')
            });

            self.setContent(Mustache.render(contentTemplate, {
                id        : QUILocale.get(lg, 'ecoyn.top.customer.id'),
                title     : QUILocale.get(lg, 'ecoyn.top.customer.title'),
                name      : QUILocale.get(lg, 'ecoyn.top.customer.name'),
                titleExtra: QUILocale.get(lg, 'ecoyn.top.customer')
            }));

            Utils.getBoard().addEvent('onChange', function () {
                self.refresh();
            });
        }
    });
});
