/**
 * @module package/quiqqer/dashboard/bin/backend/controls/cards/TopProducts
 *
 * @author www.pcsg.de (Serpil Ülker)
 */
define('package/ecoyn/dashboard/bin/backend/controls/cards/TopProducts', [

    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',

    'Ajax',
    'Locale',
    'Mustache',

    'text!package/ecoyn/dashboard/bin/backend/controls/cards/TopProducts.html'
], function (QUICard, Utils, QUIAjax, QUILocale, Mustache, contentTemplate) {
    "use strict";

    const lg = 'ecoyn/dashboard';

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/TopProducts',

        Binds: [
            '$onCreate'
        ],

        options: {},

        initialize: function (options) {
            this.parent(options);

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }


            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getTopProducts', function (result) {
                    const data = JSON.parse(result);

                    const Tbody = self.getElm().getElement('tbody');
                    Tbody.set('html', '');

                    let i, len, entry, Row;

                    const click = function (event) {
                        let Target = event.target;

                        if (Target.nodeName !== 'TR') {
                            Target = Target.getParent('tr');
                        }

                        window.parent.require([
                            'package/quiqqer/products/bin/controls/products/Product',
                            'utils/Panels'
                        ], function (ProductPanel, PanelUtils) {
                            PanelUtils.openPanelInTasks(
                                new ProductPanel({
                                    productId: Target.get('data-productid')
                                })
                            );
                        });
                    };

                    for (i = 0, len = data.length; i < len; i++) {
                        entry = data[i];

                        Row = new Element('tr', {
                            'class'         : 'can-be-hovered',
                            'artno'         : entry.artno,
                            'name'          : entry.name,
                            'data-productid': entry.id,

                            html: '' +
                                  '<td>' + entry.artno + '</td>' +
                                  '<td>' + entry.name + '</td>'
                        }).inject(Tbody);

                        Row.getElements('td').addEvent('click', click);
                    }

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            const self = this;

            if (!Utils.getBoard()) {
                return;
            }

            this.$Content.addClass('card-table ecoyn-dashboard-top-product');
            this.$Content.removeClass('card-body');

            this.getElm().classList.add('col-sg-6');
            this.getElm().classList.add('col-sm-6');

            self.setAttributes({
                head_title: QUILocale.get(lg, 'ecoyn.top.product.head.title')
            });

            self.setContent(Mustache.render(contentTemplate, {
                articleNo : QUILocale.get('quiqqer/products', 'productNo'),
                title     : QUILocale.get(lg, 'ecoyn.top.product.title'),
                name      : QUILocale.get(lg, 'ecoyn.top.product'),
                titleextra: QUILocale.get(lg, 'ecoyn.top.product.title2')
            }));

            Utils.getBoard().addEvent('onChange', function () {
                self.refresh();
            });
        }
    });
});
